Applitools Eyes Python SDK
==========================
|pypi version| |pypi downloads| |Black Formatter|

Applitools Eyes SDK For Images and Playwright
Proxy package that additionally installs `playwright` package.

`Change log`_.

Installation
------------

Install the eyes-playwright SDK.

::

    pip install eyes-playwright

Usage
-----

Please check the applitools website for usage instructions:

-  Playwright Eyes tutorial:
   https://applitools.com/tutorials/quickstart/web/playwright/python

-  Python Images API documentation:
   https://applitools.com/docs/api-ref/category/images-python

.. _Change log: https://github.com/applitools/eyes.sdk.javascript1/blob/master/python/eyes_images/CHANGELOG.md
.. |Black Formatter| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/ambv/black
.. |pypi version| image:: https://img.shields.io/pypi/v/eyes-playwright
   :target: https://pypi.org/project/eyes-playwright/
.. |pypi downloads| image:: https://img.shields.io/pypi/dw/eyes-playwright
   :target: https://pypi.org/project/eyes-playwright/
